#! /bin/bash

#Author:	Jared Ottley
#email: 	jottley@novell.com
#date:		12/06/2005

###Changelog
#
# 11/15/2004 by JRO
#  -Added ability to choose to install optional and source ISOs
#
# 11/19/2004 by JRO
#  -Fixed initalization error of incCORECD6 variable in ISOsExist()
#
# 12/06/2004 by JRO
#  -Modified layout to reflect CD order change in Beta 5
#
# 12/10/2004 by JRO
#  -Fixed spelling errors
#  -Added more descriptive language for source directory
#
# 12/13/2004 by JRO
#  -updated iso names for sp1 ISOs
#
# 12/15/2004 by JRO
#  -SP1 CD2 or 7 or....no longer optional
#  -removed symlink creation for linux directory at net install root
#
# 12/16/2004 by JRO
#  -change all ISO names to reflect Beta5 names
#
# 12/17/2004 by James Lee and JRO
#  -fixed ISO variable name missing quote and line format
#  -change iso names to all lower case
#
# 12/23/2004 by JRO
#  -change iso file names
#
# 1/28/05 by JRO
#  -change ISO names
#  -contents of oes-linux-4-services.iso consolidated to oes-linux-2.iso
#  -updated flow to follow iso order
#
# 1/31/05 by JRO
#  -correct cd name on prompt
#
# 2/28/05 by JRO
#  -modified mount point, moved to /tmp/Novell/OES
#
# 3/4/05 by JRO
#  -modified ISO names for OES Linux FCS GM
#  -Corrected name error for core9iso5
#  -removed duplicate function call pathToISO()
#
# 4/8/05 by JRO
#  -Correct typo
#  -Added hardlinks to gpg keys
#
# 6/22/05 by JRO
#  -changed mount point to /tmp/Novell/OES/SP1
#  -added sp1 labels
#  -added sp1 cd4
#  -added links for cd4 media
#
# 7/18/05 by JRO
#  -changed ISO labels for RC1
#
# 8/18/05 by JRO
#  -added directory.yast file to the root of the install source. (102257 & 84175)
#
# 8/22/05 by JRO
#  -updated "splash screen" to show Novell Open Enterprise Server SP1
#  -updating ISO names
#  -change OES SP1 optional cd3 to cd4 (updated all referencing logic, cleaned up some mess with this)
#  -If there is interest in adding functionality to update existing install sources, let me know (jottley@novell.com).
#   Also wondering if there is a need for this same setup for creating netInstall source from CDs
#   and do we want checksum tests against the ISOs?
#
# 8/26/05 by JRO
#  -fixed broken symlink for CD3
#
# 9/2/05 by JRO
#  -fixed issue with new OES CD layout, added creation of symlinks for suse dir on OES CDs 1-3. passing error messages on attempt to copy hardlinked directories to netInstall.err
#
# 12/06/05 by Justin Grote <justin@grote.name>
#  -fixed issue when using Netinstall on an OES SP1 server that causes hardlinks from the CD to be duplicated.
#
# 12/08/2005 by Dacian Zaharia-Stremtan <stremtan@gwu.edu>
#  -add md5 tests.
#
# 12/12/2005 by JRO
#  -cleaned up formating and removed dead code
###

###############################################################################
# If you see this in your browser, and you want to download/save this file,   #
# Try right clicking on the link that brought you here, and selecting         #
# "Save as" or "Save link target as" to save it to your computer.             #
###############################################################################

if [ "`id -u`" -ne "0" ]; then
	echo "ERROR: You must be root to run this script"
	echo ""
	exit
fi

clear

BOLD_ON=`tput bold`
ATTRIBUTES_OFF=`tput sgr0`

echo ""
echo "${BOLD_ON}Novell Open Enterprise Server SP1${ATTRIBUTES_OFF}"
echo ""
echo "This script attempts to set up a directory to be used "
echo "for the root of an FTP/HTTP/NFS service for network "
echo "installations of Novell's OES SP1 from your system"
echo ""
echo "${BOLD_ON}THIS SCRIPT IS PROVIDED BY NOVELL WITHOUT WARRANTY"
echo "          USE WITH EXTREME CAUTION${ATTRIBUTES_OFF}"
echo ""
echo -n "${BOLD_ON}Are you absolutely sure you want to do this?${ATTRIBUTES_OFF} [y/N]: "
read ANSWER
case "${ANSWER}" in
	[yY] | [yY][eE][sS])
		### CONTINUE ###
		;;
	*)
		echo ".......... ABORTING .........."
		echo ""
		exit
		;;
esac

clear

echo "You will be prompted to provide: 1) the location (source "
echo "directory) where you want the root of the network installation "
echo "directory to be created. If the directory does not exist you "
echo "will be prompted to create it. 2) the location of the ISO"
echo "files that you have downloaded for Novell's OES SP1. "
echo ""
echo "The script will layout the file structure, copy the contents of "
echo "the ISO files to the source directory and create the links and "
echo "files necessary for a network installation server needed in the "
echo "source directory. "
echo ""
echo "${BOLD_ON}This script does not install or configure the necessary "
echo "applications for the FTP/HTTP/NFS service needed to provide access "
echo "to the source directory from other servers.${ATTRIBUTES_OFF} "
echo ""
echo "One of these services is necessary to perform a network install, "
echo "but are not prerequisites to running this script. " 
echo ""
echo -n "${BOLD_ON}Are you ready and do you want to continue?${ATTRIBUTES_OFF} [y/N]: "
read ANSWER
case "${ANSWER}" in
	[yY] | [yY][eE][sS])
		### CONTINUE ###
		;;
	*)
		echo ".......... ABORTING .........."
		echo ""
		exit
		;;
esac

clear

###############################################################################
### 				global variables                            ###
###									    ###
### The iso names section below can be modified to change the name of the   ###
### related iso file to be referenced by the script.			    ### 
###									    ###
###############################################################################
srcDir=""
isoDir=""

##iso names
## This section could become more confusing. It is being setup to reflect the 
## layout that will be delivered in FCS.  Check carefully to make sure that 
## the iso names are correct and that the correct image is being used. Adding 
## more descriptions for each variable.

OESiso1="oes-sp1-linux-1.iso"			## Open Enterprise Server SP1 CD1
OESiso2="oes-sp1-linux-2.iso"			## Open Enterprise Server SP1 CD2
OESiso3="oes-sp1-linux-3.iso"			## Open Enterprise Server SP1 CD3
OESiso4="oes-sp1-linux-4.iso"			## Open Enterprise Server SP1 CD4 -- optional
core9iso1="oes-sp1-linux-5-sles9-2.iso"		## SUSE LINUX Enterprise Server CD2
core9iso2="oes-sp1-linux-6-sles9-3.iso"		## SUSE LINUX Enterprise Server CD3
core9iso3="oes-sp1-linux-7-sles9-4.iso"		## SUSE LINUX Enterprise Server CD4
core9iso4="oes-sp1-linux-8-sles9-5.iso"		## SUSE LINUX Enterprise Server CD5 -- optional
core9iso5="oes-sp1-linux-9-sles9-6.iso"		## SUSE LINUX Enterprise Server CD6 -- optional

##MD5SUM##
MD5OESiso1="0ef4a918ca512b2ffa06af1d9c222053"
MD5OESiso2="ff2b3493f70e7fb7cce8506144d51106"
MD5OESiso3="f96706f675a56a403bb316d7c196b099"
MD5OESiso4="5b7a994241b72027b967715dc7c5484d"
MD5core9iso1="86e97184aae42ba6013ea7460372ffe5"
MD5core9iso2="f880b3ba92fc43add18259c9437f648d"
MD5core9iso3="bc7b88f34a8142bacbdd4d1fddd3fc50"
MD5core9iso4="7844c76fc9f39a2af9ef6751ec18af60"
MD5core9iso5="9e0fdd835e52f53906dff110515eb002"

##include optional or src iso
incCORE9CD4=""
incCORE9CD5=""

incOESCD4=""

###############################################################################
###				   functions                                ###
###############################################################################

## When they exist checksums tests should be created for the ISOs.  This includes 
## asking the user if they want to validate against the checksums, looking to see
## if the checksums files exists and if the system can validate the checksums.
## Also, look into being able to use this same script to install from CD.


function pathToSrc() {
	while [ "$srcDir" = "" ]; do
		echo Full path to install source directory \(i.e. \/srv\/ftp\/oes\/\):
		read srcDir
	done
}

function pathToISO(){
	while [ "$isoDir" = "" ]; do
		echo Full path to directory containing ISO files:
		read isoDir
	done
}

# Checks to see if the ISOs named in the global variables section exist where
# the user says they are.  If they do not the script will exit.

function ISOmd5check(){
	echo "Checking for MD5 Security Check...."
	check=`md5sum ${isoDir}/$1`
	md5check=${check%%" "*}
	if [ "$2" != ${md5check} ] 
	then
		echo "ISO file $1 has incorrect MD5 Verification number"
		echo "Please make sure you have downloaded the correct iso with"
		echo "the following MD5 sum:" 
		echo "$1"		 "$2"
		exit
	else	
		echo "MD5 Security check passed"
	fi
}

function ISOsExist(){
	echo Checking for ISO images.....
	echo Checking for OES SP1 CD1...
	if [ ! -e ${isoDir}/${OESiso1} ]; then
		echo ISO file $OESiso1 could not be found. Exiting.
		exit
	else
		echo Found.
	fi

	ISOmd5check ${OESiso1} ${MD5OESiso1}

	echo Checking for OES SP1 CD2...
	if [ ! -e ${isoDir}/${OESiso2} ]; then
		echo ISO file $OESiso2 could not be found. Exiting.
		exit
	else
		echo Found. 
	fi

	ISOmd5check ${OESiso2} ${MD5OESiso2}

	echo Checking for OES SP1 CD3...
	if [ ! -e ${isoDir}/${OESiso3} ]; then
		echo ISO file $OESiso3 could not be found. Exiting.
		exit
	else
		echo Found. 
	fi

	ISOmd5check ${OESiso3} ${MD5OESiso3}

	echo Checking for OES SP1 CD4...
	if [ ! -e ${isoDir}/${OESiso4} ]; then
		echo ISO file $OESiso4 could not be found. Skipping Source ISO.
		incOESCD4=0
	else
		echo Found.
		while [ "$incOESCD4" = "" ]; do		
			echo OES SP1 CD4 is a Source ISO. Do you want to include it?[y\|n]
			read incOESCD4
			case "$incOESCD4" in
				[yY])
					incOESCD4=1

					ISOmd5check ${OESiso4} ${MD5OESiso4}
				;;
				[nN])
					incOESCD4=0
				;;
			  	*)
					incOESCD4=""
				;;
			esac
		done
	fi

	echo Checking for Core9 CD1...
	if [ ! -e ${isoDir}/${core9iso1} ]; then
		echo ISO file $core9iso1 could not be found. Exiting.
		exit
	else
		echo Found.
	fi
        
	ISOmd5check ${core9iso1} ${MD5core9iso1}

	echo Checking for core9 CD2...
	if [ ! -e ${isoDir}/${core9iso2} ]; then
		echo ISO file $core9iso2 could not be found. Exiting.
		exit
	else
		echo Found.
	fi

	ISOmd5check ${core9iso2} ${MD5core9iso2}

	echo Checking for Core9 CD3...
	if [ ! -e ${isoDir}/${core9iso3} ]; then
		echo ISO file $core9iso3 could not be found. Exiting.
		exit
	else
		echo Found.
	fi

	ISOmd5check ${core9iso3} ${MD5core9iso3}

	echo Checking for Core9 CD4...
	if [ ! -e ${isoDir}/${core9iso4} ]; then
		echo ISO file $core9iso4 could not be found. Skipping Source ISO.
		incCORE9CD4=0
	else
		echo Found.
		while [ "$incCORE9CD4" = "" ]; do		
			echo CORE9 CD4 is a Source ISO. Do you want to include it?[y\|n]
			read incCORE9CD4
			case "$incCORE9CD4" in
				[yY])
					incCORE9CD4=1

					ISOmd5check ${core9iso4} ${MD5core9iso4}
				;;
				[nN])
					incCORE9CD4=0
				;;
			  	*)
					incCORE9CD4=""
				;;
			esac
		done
	fi

	echo Checking  for Core9 CD5...
	if [ ! -e ${isoDir}/${core9iso5} ]; then
		echo ISO file $core9iso5 could not be found. Skipping Source ISO.
		incCORE9CD5=0
	else
		echo Found.
		while [ "$incCORE9CD5" = "" ]; do		
			echo CORE9 CD5 is a Source ISO. Do you want to include it?[y\|n]
			read incCORE9CD5
			case "$incCORE9CD5" in
				[yY])
					incCORE9CD5=1

					ISOmd5check ${core9iso5} ${MD5core9iso5}
				;;
				[nN])
					incCORE9CD5=0
				;;
			  	*)
					incCORE9CD5=""
				;;
			esac
		done
	fi
}

###############################################################################
###				    User input                              ###
###############################################################################

srcDirExists=0

while [ "$srcDirExists" -lt "1" ]; do
	pathToSrc

	if [ -x $srcDir ]; then
		if [ $srcDir = "/" ]; then
			echo Root\(/\) is not a valid source directory.
			srcDir=""
		else
			srcDirExists=1
		fi

	else
		echo The directory does not exist. Do you want to create it?[yes\|no]
		read createDir

		case "$createDir" in
			"yes") 
				mkdir -p $srcDir
				srcDirExists=1
				echo Directory created.
			;;
			"no")
				srcDir=""
				pathToSrc
				createDir=""
			;;
			*) 
				srcDir=""				
				createDir=""
			;; 
		esac
	fi
done

isoDirExists=0

while [ "$isoDirExists" -lt "1" ]; do	
	pathToISO
	if [ -x $isoDir ]; then
		isoDirExists=1
	else
		isoDir=""
		echo The ISO directory specified does not exist
	fi

done	

ISOsExist

###############################################################################
###				      	Main                                ###
###############################################################################

###make directory structure
echo Make Directory Structure

mkdir -p ${srcDir}/sles9/CD1
mkdir -p ${srcDir}/sles9/CD2
mkdir -p ${srcDir}/sles9/CD3

if [ "$incOESCD4" -gt  "0" ]; then
	mkdir -p ${srcDir}/sles9/CD4
fi

mkdir -p ${srcDir}/core9/CD1
mkdir -p ${srcDir}/core9/CD2
mkdir -p ${srcDir}/core9/CD3

if [ "$incCORE9CD4" -gt "0" ]; then
	mkdir -p ${srcDir}/core9/CD4
fi

if [ "$incCORE9CD5" -gt "0" ]; then
	mkdir -p ${srcDir}/core9/CD5
fi

###copy files from iso
echo Copy From ISOs

mkdir -p /tmp/Novell/OES/SP1

echo Copying OES SP1 CD1...
mount ${isoDir}/${OESiso1} -o loop /tmp/Novell/OES/SP1
tar -c -C /tmp/Novell/OES/SP1 . | tar -x -C ${srcDir}/sles9/CD1
umount /tmp/Novell/OES/SP1

echo Copying OES SP1 CD2...
mount ${isoDir}/${OESiso2} -o loop /tmp/Novell/OES/SP1
tar -c -C /tmp/Novell/OES/SP1 . | tar -x -C ${srcDir}/sles9/CD2
umount /tmp/Novell/OES/SP1

echo Copying OES SP1 CD3...
mount ${isoDir}/${OESiso3} -o loop /tmp/Novell/OES/SP1
tar -c -C /tmp/Novell/OES/SP1 . | tar -x -C ${srcDir}/sles9/CD3
umount /tmp/Novell/OES/SP1


if [ "$incOESCD4" -gt "0" ]; then
	echo Copying OES SP1 CD4...
	mount ${isoDir}/${OESiso4} -o loop /tmp/Novell/OES/SP1
	tar -c -C /tmp/Novell/OES/SP1 . | tar -x -C ${srcDir}/sles9/CD4
	umount /tmp/Novell/OES/SP1
fi

echo Copying Core9 CD1...
mount ${isoDir}/${core9iso1} -o loop /tmp/Novell/OES/SP1
tar -c -C /tmp/Novell/OES/SP1 . | tar -x -C ${srcDir}/core9/CD1
umount /tmp/Novell/OES/SP1

echo Copying Core9 CD2...
mount ${isoDir}/${core9iso2} -o loop /tmp/Novell/OES/SP1
tar -c -C /tmp/Novell/OES/SP1 . | tar -x -C ${srcDir}/core9/CD2
umount /tmp/Novell/OES/SP1

echo Copying Core9 CD3...
mount ${isoDir}/${core9iso3} -o loop /tmp/Novell/OES/SP1
tar -c -C /tmp/Novell/OES/SP1 . | tar -x -C ${srcDir}/core9/CD3

umount /tmp/Novell/OES/SP1

if [ "$incCORE9CD4" -gt "0" ]; then
	echo Copying Core9 CD4...
	mount ${isoDir}/${core9iso4} -o loop /tmp/Novell/OES/SP1
	tar -c -C /tmp/Novell/OES/SP1 . | tar -x -C ${srcDir}/core9/CD4
	umount /tmp/Novell/OES/SP1
fi

if [ "$incCORE9CD5" -gt "0" ]; then
	echo Copying Core9 CD5...
	mount ${isoDir}/${core9iso5} -o loop /tmp/Novell/OES/SP1
	cp -r /tmp/Novell/OES/SP1/* ${srcDir}/core9/CD5
	umount /tmp/Novell/OES/SP1
fi

rm -rf /tmp/Novell/OES/SP1

###setup install root
echo Setup Install Root

cd $srcDir

ln -s sles9/CD1/boot boot
ln -s sles9/CD1/content content
ln -s sles9/CD1/control.xml control.xml
ln -s sles9/CD1/media.1 media.1
ln -s sles9/CD2/media.2 media.2
ln -s sles9/CD3/media.3 media.3

if [ "$incOESCD4" -gt "0" ]; then
	ln -s sles9/CD4/media.4 media.4
fi

##Copy gpg keys to root of netInstall directory
cp sles9/CD1/gpg-*.asc .

mkdir ${srcDir}/yast

echo "/sles9/CD1" > ${srcDir}/yast/instorder
echo "/core9/CD1" >> ${srcDir}/yast/instorder

#seperated by tabs
echo "/sles9/CD1	/sles9/CD1" > ${srcDir}/yast/order
echo "/core9/CD1	/core9/CD1" >> ${srcDir}/yast/order

#make directory.yast file
touch directory.yast
ls >directory.yast

echo ""
echo "............................................................"
echo "...... Network Installation directory setup complete ......."
echo "............................................................"
echo ""
echo "************************************************************"
echo "***** Don't Forget to setup your FTP/HTTP/NFS Service ******"
echo "************************************************************"
echo ""
